import os
import json


config_file_path = (os.environ.get('AUTOMLAPI_CONFIG_FILE_PATH') or 
                    os.path.join(os.path.expanduser("~"), 'npaws.cfg'))
CONFIG = json.load(open(config_file_path, 'r'))


AWS_ACC_KEY_ID = CONFIG.get("AWS_ACC_KEY_ID")
AWS_SEC_ACC_KEY = CONFIG.get("AWS_SEC_ACC_KEY")
AWS_REGION_NAME = CONFIG.get("AWS_REGION_NAME")
USER_POOL_ID = CONFIG.get("USER_POOL_ID")
CLIENT_ID = CONFIG.get("CLIENT_ID")
CLIENT_SECRET = CONFIG.get("CLIENT_SECRET")
DB_HOST = CONFIG.get("DB_HOST")
DB_USER = CONFIG.get("DB_USER")
DB_PASSWORD = CONFIG.get("DB_PASSWORD")


import boto3
from .config import (
    AWS_ACC_KEY_ID,
    AWS_SEC_ACC_KEY,
    AWS_REGION_NAME
)


class Boto3Client():
    """
    """
    
    def __init__(self,
                 service: str,
                 aws_access_key_id: str = AWS_ACC_KEY_ID,
                 aws_secret_access_key: str = AWS_SEC_ACC_KEY,
                 region_name: str = AWS_REGION_NAME):
        """
        """
        self._client = boto3.client(service,
                                    aws_access_key_id=aws_access_key_id,
                                    aws_secret_access_key=aws_secret_access_key,
                                    region_name=region_name)
        self._inherit_from_boto3()
    
    def _inherit_from_boto3(self):
        """
        """
        for attr in self._client.__dir__():
            if not attr.startswith('__'):
                setattr(self, attr, getattr(self._client, attr))